# Общие импорты для всех примеров
from example.llm_config import (
    claude_3_5_haiku,  # noqa: F401
    claude_3_7_sonnet,  # noqa: F401
    claude_opus_4,  # noqa: F401
    claude_sonnet_4,  # noqa: F401
    deepseek_chat,  # noqa: F401
    deepseek_reasoner,  # noqa: F401
    gemini_2_0_flash_001,  # noqa: F401
    gemini_2_5_flash,  # noqa: F401
    gemini_2_5_pro,  # noqa: F401
    giga_chat,  # noqa: F401
    giga_chat_2,  # noqa: F401
    giga_chat_2_max,  # noqa: F401
    giga_chat_2_pro,  # noqa: F401
    giga_chat_max,  # noqa: F401
    giga_chat_pro,  # noqa: F401
    gpt_4_1,  # noqa: F401
    gpt_4_1_mini,  # noqa: F401
    gpt_4_1_nano,  # noqa: F401
    gpt_4_5_preview,  # noqa: F401
    gpt_4o,  # noqa: F401
    gpt_4o_mini,  # noqa: F401
    gpt_5,  # noqa: F401
    gpt_5_chat_latest,  # noqa: F401
    gpt_5_mini,  # noqa: F401
    gpt_5_nano,  # noqa: F401
    gpt_oss_120b,  # noqa: F401
    grok_3,  # noqa: F401
    grok_3_fast,  # noqa: F401
    grok_3_mini,  # noqa: F401
    llama_4_maverick_17b_128e_instruct,  # noqa: F401
    llama_4_scout_17b_16e_instruct,  # noqa: F401
    o3_2025_04_16,  # noqa: F401
    o4_mini_2025_04_16,  # noqa: F401
    openrouter,  # noqa: F401
    qwen_3_32b,  # noqa: F401
)
